pub async fn launch_stealth_session(
url: &str,
headed: bool,
) -> Result<BrowserSession, TailFinError>Expand description
Launch a stealth browser navigated to url with anti-detection.
pub async fn launch_stealth_session(
url: &str,
headed: bool,
) -> Result<BrowserSession, TailFinError>Launch a stealth browser navigated to url with anti-detection.